Module: UDAPSecurityTestKit::ClientWaitDialogDescriptions
- Included in:
- UDAPClientAccessAuthorizationCodeInteraction, UDAPClientAccessClientCredentialsInteraction
- Defined in:
- lib/udap_security_test_kit/client_suite/client_descriptions.rb
Instance Method Summary collapse
- #wait_dialog_access_response_and_continue_suffix(client_id, resume_pass_url) ⇒ Object
- #wait_dialog_authorization_code_access_prefix(client_id, fhir_base_url) ⇒ Object
- #wait_dialog_client_credentials_access_prefix(client_id, fhir_base_url) ⇒ Object
Instance Method Details
#wait_dialog_access_response_and_continue_suffix(client_id, resume_pass_url) ⇒ Object
58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/udap_security_test_kit/client_suite/client_descriptions.rb', line 58 def wait_dialog_access_response_and_continue_suffix(client_id, resume_pass_url) <<~SUFFIX Inferno will respond to requests with either: - A resource from the Bundle in the **Available Resources** input if the request is a read matching a resource type and id found in the Bundle. - Otherwise, the contents of the **Default FHIR Response** if provided. - Otherwise, an OperationOutcome indicating nothing to echo. [Click here](#{resume_pass_url}?token=#{client_id}) once you performed the data access. SUFFIX end |
#wait_dialog_authorization_code_access_prefix(client_id, fhir_base_url) ⇒ Object
45 46 47 48 49 50 51 52 53 54 55 56 |
# File 'lib/udap_security_test_kit/client_suite/client_descriptions.rb', line 45 def (client_id, fhir_base_url) <<~PREFIX **Access** Use the registered client id (#{client_id}) to obtain an access token using the UDAP [consumer-facing](https://hl7.org/fhir/us/udap-security/STU1/consumer.html) or [B2B authorization code flow](https://hl7.org/fhir/us/udap-security/STU1/b2b.html) and use that token to access a FHIR endpoint under the simulated server's base URL `#{fhir_base_url}` PREFIX end |
#wait_dialog_client_credentials_access_prefix(client_id, fhir_base_url) ⇒ Object
33 34 35 36 37 38 39 40 41 42 43 |
# File 'lib/udap_security_test_kit/client_suite/client_descriptions.rb', line 33 def wait_dialog_client_credentials_access_prefix(client_id, fhir_base_url) <<~PREFIX **Access** Use the registered client id (#{client_id}) to obtain an access token using the [UDAP B2B client credentials flow](https://hl7.org/fhir/us/udap-security/STU1/b2b.html) and use that token to access a FHIR endpoint under the simulated server's base URL `#{fhir_base_url}` PREFIX end |